@@ -4,7 +4,7 @@
 #ifdef CLANG_DIAG_IGNORE
   CLANG_DIAG_IGNORE (-Wpragma-pack)
 #endif
-#include "../../src/decode.c"
+#include "decode.c"
 #ifdef CLANG_DIAG_IGNORE
   CLANG_DIAG_RESTORE
 #endif
@@ -56,6 +56,8 @@ read_two_byte_offset_tests (void)
 int
 main (int argc, char const *argv[])
 {
+  loglevel = is_make_silent() ? 0 : 2;
+
   read_literal_length_tests ();
   read_long_compression_offset_tests ();
   read_two_byte_offset_tests ();
